@@ -41,16 +41,16 @@ def blog_post_list(request, tag=None, year=None, month=None, username=None,
     except ValueError:
         page_num = 1
     try:
-        posts = paginator.page(page_num)
+        blog_posts = paginator.page(page_num)
     except (EmptyPage, InvalidPage):
-        posts = paginator.page(paginator.num_pages)
-    page_range = posts.paginator.page_range
+        blog_posts = paginator.page(paginator.num_pages)
+    page_range = blog_posts.paginator.page_range
     max_links = blog_settings.BLOG_POST_MAX_PAGING_LINKS
     if len(page_range) > max_links:
-        start = min(posts.paginator.num_pages - max_links, 
+        start = min(blog_posts.paginator.num_pages - max_links, 
             max(0, blog_posts.number - (max_links / 2) - 1))
         page_range = page_range[start:start + max_links]
-    context = {"posts": posts, "page_range": page_range, "tag": tag, 
+    context = {"blog_posts": blog_posts, "page_range": page_range, "tag": tag, 
         "year": year, "month": month, "user": user, "use_disqus": use_disqus}
     return render_to_response(template, context, RequestContext(request))
 
