@@ -26,6 +26,11 @@ def page(request, slug, template="pages/page.html"):
     """
     page = get_object_or_404(Page.objects.published(request.user), slug=slug)
     context = {"page": page,}
-    t = select_template(["pages/%s.html" % slug, template])
+    templates = ["pages/%s.html" % slug]
+    content_model = page.get_content_model()
+    if content_model is not None:
+        templates.append("pages/%s.html" % content_model)
+    templates.append(template)
+    t = select_template()
     return HttpResponse(t.render(RequestContext(request, context)))
 
