@@ -36,15 +36,17 @@ CACHE_MIDDLEWARE_KEY_PREFIX = project_dir
 
 # Apps.
 INSTALLED_APPS = (
-    "mezzanine.core",
-    "mezzanine.blog",
-    "mezzanine.pages",
-    "mezzanine.twitter",
     "django.contrib.admin",
     "django.contrib.auth",
     "django.contrib.contenttypes",
     "django.contrib.sessions",
     "django.contrib.sites",
+    "django.contrib.redirects",
+    "mezzanine.core",
+    "mezzanine.blog",
+    "mezzanine.pages",
+    "mezzanine.twitter",
+    "mezzanine.forms",
 )
 
 TEMPLATE_CONTEXT_PROCESSORS = (
@@ -83,7 +85,8 @@ if not (len(sys.argv) > 1 and sys.argv[1] == "test"):
         except ImportError:
             pass
         else:
-            INSTALLED_APPS = (app,) + INSTALLED_APPS
+            INSTALLED_APPS += (app,)
+INSTALLED_APPS = sorted(list(INSTALLED_APPS), reverse=True)
 
 # Optional app settings.
 if "debug_toolbar" in INSTALLED_APPS:
